### Best Box
Feasible Optimization | ParametricSoln v0.2.1
by: Charlie Taylor | March 06, 2023

Design Variable Summary
Design Variables (nominal values)
Name | Value | Units | Description
b | 10 | in | Height of Box (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
a | 7.07107 * -----> | in | Base Dimension of Cardboard (in) (a varies to make Volume = 500 cuin) | >1 | <50
Volume | 500 | cuin | Box Volume (cuin) | --- | ---
boxSurfArea | 332.843 | sqin | Box Surface Area (sqin) | --- | ---

PRIOR TO MINIMIZE OPTIMIZATION
    ParametricSoln: Feasible Optimization

    ====================== OPTIMIZATION DESIGN VARIABLES =======================
          name         value        minimum   maximum
             b           10            2           10 Height of Box  (in)

     Figure of Merit: Box Surface Area (boxSurfArea) = 332.843 sqin <== Minimize
    ============================================================================

AFTER MINIMIZE OPTIMIZATION
    ParametricSoln: Feasible Optimization

    ====================== OPTIMIZATION DESIGN VARIABLES =======================
          name         value        minimum   maximum
             b            5            2           10 Height of Box  (in)

     Figure of Merit: Box Surface Area (boxSurfArea) = 300 sqin <== Minimize
    ============================================================================

System Sensitivity
Design Variables (nominal values)
Name | Value | Units | Description
b | 5 | in | Height of Box (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
a | 10 * -----> | in | Base Dimension of Cardboard (in) (a varies to make Volume = 500 cuin) | >1 | <50
Volume | 500 | cuin | Box Volume (cuin) | --- | ---
boxSurfArea | 300 | sqin | Box Surface Area (sqin) | --- | ---

Design Variable Summary
Design Variables (nominal values)
Name | Value | Units | Description
b | 5 | in | Height of Box (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
a | 10 * -----> | in | Base Dimension of Cardboard (in) (a varies to make Volume = 500 cuin) | >1 | <50
Volume | 500 | cuin | Box Volume (cuin) | --- | ---
boxSurfArea | 300 | sqin | Box Surface Area (sqin) | --- | ---

    Parametric Solutions
    parasol v0.2.1
    contact: C. Taylor, cet@appliedpython.com